==> jakarta-faces-tck-4.0.2.zip: faces-tck-4.0.2/tck/faces23/facesConverter/src/test/java/ee/jakarta/tck/faces/test/javaee8/facesConverter/Issue4913IT.java <==
/*
 * Copyright (c) 2021 Contributors to the Eclipse Foundation.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */
package ee.jakarta.tck.faces.test.javaee8.facesConverter;

import static java.lang.System.getProperty;
import static org.jboss.shrinkwrap.api.ShrinkWrap.create;
import static org.junit.Assert.assertEquals;

import java.io.File;
import java.net.URL;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.shrinkwrap.api.importer.ZipImporter;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import com.gargoylesoftware.htmlunit.WebClient;
import com.gargoylesoftware.htmlunit.html.DomElement;
import com.gargoylesoftware.htmlunit.html.HtmlPage;

import jakarta.faces.application.ResourceDependency;
import jakarta.faces.convert.FacesConverter;
import jakarta.inject.Inject;

@RunWith(Arquillian.class)
public class Issue4913IT {

    @ArquillianResource
    private URL webUrl;
    private WebClient webClient;

    @Deployment(testable = false)
    public static WebArchive createDeployment() {
        return create(ZipImporter.class, getProperty("finalName") + ".war")
                .importFrom(new File("target/" + getProperty("finalName") + ".war"))
                .as(WebArchive.class);
    }

    @Before
    public void setUp() {
        webClient = new WebClient();
    }

    @After
    public void tearDown() {
        webClient.close();
    }

    /**
     * @see Inject
     * @see ResourceDependency
     * @see FacesConverter#managed()
     * @see https://github.com/eclipse-ee4j/mojarra/issues/4913
     */
    @Test
    public void test() throws Exception {
        HtmlPage page = webClient.getPage(webUrl + "issue4913.xhtml");
        webClient.waitForBackgroundJavaScript(3000);
        validateMarkup(page);

        // Refresh page 
        page = webClient.getPage(webUrl + "issue4913.xhtml");
        webClient.waitForBackgroundJavaScript(3000);
        validateMarkup(page);
    }
    
    private static void validateMarkup(HtmlPage page) {
        DomElement issue4913Converter = page.getElementById("issue4913Converter");
        assertEquals("Converter is invoked", "value is successfully converted in a managed converter", issue4913Converter.asNormalizedText());

        DomElement issue4913ResourceDependency = page.getElementById("issue4913ResourceDependency");
        assertEquals("Resource dependency is injected", "resource dependency is successfully injected via a managed converter", issue4913ResourceDependency.asNormalizedText());
    }
}

==> jakarta-faces-tck-4.1.2.zip: faces-tck-4.1.2/tck/faces23/facesConverter/src/test/java/ee/jakarta/tck/faces/test/javaee8/facesConverter/Issue4913IT.java <==
/*
 * Copyright (c) 2021 Contributors to the Eclipse Foundation.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */
package ee.jakarta.tck.faces.test.javaee8.facesConverter;

import static java.lang.System.getProperty;
import static org.jboss.shrinkwrap.api.ShrinkWrap.create;
import static org.junit.Assert.assertEquals;

import java.io.File;
import java.net.URL;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.shrinkwrap.api.importer.ZipImporter;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import org.htmlunit.WebClient;
import org.htmlunit.html.DomElement;
import org.htmlunit.html.HtmlPage;

import jakarta.faces.application.ResourceDependency;
import jakarta.faces.convert.FacesConverter;
import jakarta.inject.Inject;

@RunWith(Arquillian.class)
public class Issue4913IT {

    @ArquillianResource
    private URL webUrl;
    private WebClient webClient;

    @Deployment(testable = false)
    public static WebArchive createDeployment() {
        return create(ZipImporter.class, getProperty("finalName") + ".war")
                .importFrom(new File("target/" + getProperty("finalName") + ".war"))
                .as(WebArchive.class);
    }

    @Before
    public void setUp() {
        webClient = new WebClient();
    }

    @After
    public void tearDown() {
        webClient.close();
    }

    /**
     * @see Inject
     * @see ResourceDependency
     * @see FacesConverter#managed()
     * @see https://github.com/eclipse-ee4j/mojarra/issues/4913
     */
    @Test
    public void test() throws Exception {
        HtmlPage page = webClient.getPage(webUrl + "issue4913.xhtml");
        webClient.waitForBackgroundJavaScript(3000);
        validateMarkup(page);

        // Refresh page 
        page = webClient.getPage(webUrl + "issue4913.xhtml");
        webClient.waitForBackgroundJavaScript(3000);
        validateMarkup(page);
    }
    
    private static void validateMarkup(HtmlPage page) {
        DomElement issue4913Converter = page.getElementById("issue4913Converter");
        assertEquals("Converter is invoked", "value is successfully converted in a managed converter", issue4913Converter.asNormalizedText());

        DomElement issue4913ResourceDependency = page.getElementById("issue4913ResourceDependency");
        assertEquals("Resource dependency is injected", "resource dependency is successfully injected via a managed converter", issue4913ResourceDependency.asNormalizedText());
    }
}
